#!/bin/tcsh
#
# Tool to retrieve information needed for issuing an SAMG release 2019
# license for this Linux rsp. Mac machine.
#
# Base: FLEXlm V11.16.6.0
#
set debuglevel=0
# ack && output handling: cautious
#set debuglevel=1   

set msg=""
set err=0
@ exitcode=0

set outfile="FLEXlmMachineInfo.txt"

echo "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
echo "+++ Tool to retrieve information needed for issuing either:"
echo "+++"
echo "+++ - a NODE LOCKED license for SAMG release 2019"
echo "+++   enabling run of SAMG applications on THIS Linux rsp. Mac machine"
echo "+++"
echo "+++ - or a FLOATING license for SAMG release 2019"
echo "+++   with THIS machine being [one of] the LICENSE SERVER[s],"
echo "+++   serving SAMG licenses for machines in [parts of] this IP network"
echo "+++   IMPORTANT:"
echo "+++   - ALL machines to be used for runs of SAMG applications MUST be"
echo "+++     IP-connected with this license server machine!"
echo "+++   - If you want a license for THREE-SERVER REDUNTANT license servers"
echo "+++     (license server triad), please be sure to supply us with the"
echo "+++     respective information for each of the three machines."
echo "+++   - If you intended to run SAMG's license server combined with other"
echo "+++     license servers and several FlexNet hostids are listed for this"
echo "+++     machine, please point out which of them is used by the"
echo "+++     combined license server[s]."
echo "+++"
echo "+++   - ADDITIONALLY to the output below we need the [range of] IP-adresses"
echo "+++     of the machines supposed to run SAMG applications."
echo "+++"
echo "+++ ATTENTION:"
echo "+++ All Hardware Cards of this machine must be set up and activated in"
echo "+++ exactly the same way as they will be when running SAMG applications"
echo "+++ rsp. SAMG's license server daemon!"
echo "+++"
echo "+++ The information will be written into file"
echo "+++ ${outfile}"
echo ""
echo "+++ Press ENTER to continue or Ctrl-C to quit."
set cont = $<

goto start

start:
echo ""
foreach o ($outfile)
  if (-e ./$o) then
   'rm' -f $outfile
  endif
end

# os: Linux: Linux; Mac: Darwin
set os = `uname`
set arch = `uname -m`
set osind = "undef"
if ($debuglevel) echo "os: $os; arch: $arch; osind: $osind"

switch ($arch)
case "i386":
case "i686":
   echo "Sorry, SAMG release 2019 is not available for $os 32bit"
   @ exitcode=9
   goto fin
endsw

switch ($os)
case "Linux":
   if ($debuglevel) echo "Checking Linux: os: $os; arch: $arch; osind: $osind"
   switch ($arch)
   case "x86_64":
      set osind = "LinuxX64"
      if ($debuglevel) echo "OK: Linux: os: $os; arch: $arch; osind: $osind"
      goto doit
   case "ia64":
      set osind = "LinuxIA64"
      if ($debuglevel) echo "Sorry, SAMG is not available for $osind"
      @ exitcode=9
      goto fin
   default:
      set msg="Information not available for $os on $arch"
      if ($debuglevel) echo "NOT OK: Linux: os: $os; arch: $arch; osind: $osind"
      @ exitcode=9
      goto fin
   endsw
case "Darwin":
   if ($debuglevel) echo "Checking Mac: os: $os; arch: $arch; osind: $osind"
   switch ("$arch")
   case "x86_64":
      set osind = "Mac"
      if ($debuglevel) echo "OK: Mac: os: $os; arch: $arch; osind: $osind"
      goto doit
   default:
      set msg="Information not available for $os on $arch"
      if ($debuglevel) echo "NOT OK: Mac: os: $os; arch: $arch; osind: $osind"
      @ exitcode=9
      goto fin
   endsw
default:
   set msg="SAMG is only vailable for Linux or Mac (Darwin), not for OS: $os"
   if ($debuglevel) echo "NOT OK: OS unknown: os: $os; arch: $arch; osind: $osind"
   @ exitcode=99
   goto fin
endsw

doit:
if ($debuglevel) echo "STARTING: os: $os; arch: $arch; osind: $osind"
echo "SAMG release 2019 license request" > $outfile
echo "=================================" >> $outfile
echo "+++ OS: $osind ($os $arch)"        >> $outfile
@ exitcode=0
echo "+++ Ethernet hostid:"              >> $outfile
$osind/lmutil lmhostid -ether            >> $outfile
@ exitcode+=$status
echo "+++ Internet hostid:"              >> $outfile
$osind/lmutil lmhostid -internet         >> $outfile
@ exitcode+=$status
echo "+++ Hostname:"                     >> $outfile
$osind/lmutil lmhostid -hostname         >> $outfile
@ exitcode+=$status

check1:
if ($debuglevel) echo "check1: exitcode: $exitcode; os: $os; arch: $arch; osind: $osind"
if !($exitcode) goto thatsit
echo "+++ ERROR: No MachineInfo for this environment. Exitcode: $exitcode" >> $outfile
'more' $outfile
goto failure

thatsit:
echo ""
echo ""
echo "+++ Contents of file $outfile : "
echo ""
'more' $outfile

echo ""
echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
echo "+++ For requiring an SAMG release 2019 license please attach file"
echo "+++             ${outfile} "
echo "+++ to an email to:"
echo "+++                  samg@scapos.com "
echo "+++ "
echo "+++ This email should additionally contain the following information and data:"
echo "+++ - The name and full postal address of your company."
echo "+++ - The name and email address of the person to obtain the license."
echo "+++ "
echo "+++ - Whether you require a NODE LOCKED license or a FLOATING LICENSE plus,"
echo "+++   in case of a FLOATING LICENSE:"
echo "+++    - The range of IP addresses of the machines to be used for SAMG runs."
echo "+++    - If this machine is to be used in a license server triad:"
echo "+++      - The lmhostid of the other machines of that triad."
echo "+++      - If several hostids are listed for this machine:"
echo "+++        - Which of these hostids is to be used for the license server?"
echo "+++ "
echo "+++ - In case multiple Ethernet hostids are listed above, please "
echo "+++   point us to a permanent or stable hostid to identify your machine."
echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"

goto fin

failure:
echo "+++ $0 aborted"
if (("$osind" == "Linux") || ("$osind" == "LinuxX64")) then
   echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
   echo "+++ If you encountered errormessages:"
   echo "+++            command not found"
   echo "+++ this machine probably is installed without the"
   echo "+++    Linux Standard Base (LSB 4) package ."
   echo "+++ Please let your sysadmin install the package and try again."
   echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
   goto fin
endif
goto fin

fin:
#REM ******************
#REM * clear and exit *
#REM ******************
echo $msg

unset os
unset arch
unset osind
unset msg
unset debuglevel

exit $exitcode
